#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pytorch_revgrad']

package_data = \
{'': ['*']}

package_dir = \
{'': 'src'}

install_requires = \
['numpy', 'torch>=1.0.0']

extras_require = \
{'dev': ['ipython'],
 'test': ['pytest', 'pytest-cov', 'flake8', 'pytest-flake8', 'coveralls']}

setup(name='pytorch_revgrad',
      version='0.2.0',
      description='A pytorch module (and function) to reverse gradients.',
      author='Jan Freyberg',
      author_email='jan.freyberg@gmail.com',
      url='https://github.com/janfreyberg/pytorch-revgrad',
      packages=packages,
      package_data=package_data,
      package_dir=package_dir,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )
